@@ -1319,7 +1319,8 @@ class ConvertFileUpdateInput:
         
         if self._writer_parameters:
             body["writerParameters"] = [{"name": p[0], "value": p[1]} for p in self._writer_parameters]
-
+        
+        return body
 
 class ConvertInputBase:
     def __init__(
@@ -2172,7 +2173,7 @@ class TransferClient():
         pipeline = TransferPipeline(None, FileWriter())
         return DownloadTransferProcess(source, pipeline, self._transfer_process_awaiter, self._transfer_process_invoker)
 
-    def create_dataset_update_from_file(self, project_id, dataset_id, file_path:str, max_parallelism:int=2, block_size:int=20*1024*1024) -> InPlaceDatasetTransferProcess:
+    def create_dataset_update_from_file(self, project_id, dataset_id, file_path:str, original_file_name:str, max_parallelism:int=2, block_size:int=20*1024*1024) -> InPlaceDatasetTransferProcess:
         """
         Creates a dataset download/convert task. When executed, the task will create a url where the output of the conversion can be downloaded.
 
@@ -2186,7 +2187,7 @@ class TransferClient():
         """
         transfer_source = DatasetTransferSource(dataset_id)
         pipeline = TransferPipeline(None, None)
-        update_source = LocalFileTransferSource(file_path)
+        update_source = LocalFileTransferSource(file_path, original_file_name, max_parallelism, block_size)
         return InPlaceDatasetTransferProcess(
             transfer_source,
             update_source,
